@@ -1,7 +1,23 @@
-package Search::Elasticsearch::Client::6_0::Role::Scroll;
-$Search::Elasticsearch::Client::6_0::Role::Scroll::VERSION = '6.80_01'; # TRIAL
+# Licensed to Elasticsearch B.V. under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Elasticsearch B.V. licenses this file to you under
+# the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
-$Search::Elasticsearch::Client::6_0::Role::Scroll::VERSION = '6.8001';use Moo::Role;
+package Search::Elasticsearch::Client::6_0::Role::Scroll;
+$Search::Elasticsearch::Client::6_0::Role::Scroll::VERSION = '7.30';
+use Moo::Role;
 requires 'finish';
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Devel::GlobalDestruction;
@@ -64,7 +80,7 @@ Search::Elasticsearch::Client::6_0::Role::Scroll - Provides common functionality
 
 =head1 VERSION
 
-version 6.80_01
+version 7.30
 
 =head1 AUTHOR
 
